@@ -1578,6 +1578,18 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Library is too large to sync.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Waiting for confirmation to delete files</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Confirm to bulk delete files in library &quot;%1&quot; ?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted &quot;%1&quot; and %2 more files.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -2228,6 +2240,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>no permissions to create a upload link</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Waiting for confirmation to delete files</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2609,6 +2625,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>failed to read %1</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileExtensionHandler</name>
@@ -2976,10 +2996,6 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Do not verify server certificate in HTTPS syncing</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Enable syncing with an existing folder with a different name</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Advanced</source>
         <translation type="unfinished"/>
@@ -3036,6 +3052,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Hide Windows incompatibility paths Message</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Confirm before bulk deleting files more than</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SharedItemDelegate</name>
